@@ -42,8 +42,7 @@ class BaseCacheMixin:
 
     @log
     def flush_cache(self):
-        """Delete cache for current endpoint"""
-        self._memory_cache = None
+        """Delete Redis cache for current endpoint"""
         data = cache.get(self._cache_key)
         if data:
             data.pop(self._data_key, False)
@@ -74,10 +73,12 @@ class CacheMixin(BaseCacheMixin):
     def _post(self, payload: dict):
         self._payload = payload
         super()._post(payload)
+        self._memory_cache = None
         self._flush_cache_related_points()
 
     def _post_file(self, file, file_name, type_):
         super()._post_file(file, file_name, type_)
+        self._memory_cache = None
         self._flush_cache_related_points()
 
 
@@ -96,6 +97,7 @@ class CacheObjectMixin(BaseCacheMixin):
     def _put(self, payload: dict):
         self._payload = payload
         super()._put(payload)
+        self._memory_cache = None
         self._flush_cache_related_points()
 
     @property
@@ -108,11 +110,9 @@ class FlushCache:
 
     def __init__(self, user: User):
         self._user = user
-        self._memory_cache = None
 
     @log
     def flush_cache(self):
-        self._memory_cache = None
         cache.delete(self._cache_key)
 
     @property
